<h1 align="center">khoj-assistant is now khoj</h1>

<div align="center">
<b>This package has been renamed. Use `pip install khoj` instead.</b>
<br />
New package: ![](https://pypi.org/project/khoj/)
</div>

<br />

<div align="center">

[🤖 Read Docs](https://docs.khoj.dev)
<span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
[🏮 Khoj Cloud](https://khoj.dev)
<span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
[💬 Get Involved](https://discord.gg/BDgyabRM6e)
<span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
[📚 Read Blog](https://blog.khoj.dev)

</div>
